from .executable_command_base import ExecutableCommandBase


class SesamCoreCommand(ExecutableCommandBase):
    """
    The base class for the Sesam core commands.
    """

    def __init__(
        self,
        command: str = "fatigue",
        input_file_name: str = "SesamCore_input.json",
        options: str = "-hs",
    ):
        """
        Initializes a new instance of the SesamCoreCommand class.

        Args:
            command (str): The Sesam Core command to run. Defaults to "fatigue".
            input_file_name (str, optional): The name of the Sesam Core input file.
                Defaults to "SesamCore_input.json".
            options (str): The options to use with Sesam Core excluding the input file.
                Defaults to "-hs".
        """
        super().__init__(working_dir="")
        self.command = command
        self.input_file_name = input_file_name
        self.options = options
        self.executable_folder = ""
        self.arguments = ""

    @property
    def type(self) -> str:
        """
        Get the type of the command.

        Returns:
            str: The type of the command.
        """
        return "DNV.Sesam.Commons.SesamCommands.SesamCore.SesamCoreCommand, DNV.Sesam.Commons.SesamCommands"

    @property
    def arguments(self) -> str:
        """
        Gets the arguments for the command-line executable.

        Returns:
            str: A string containing the command-line arguments for the executable.
        """
        return self.Arguments

    @arguments.setter
    def arguments(self, value: str):
        """
        Sets the arguments for the command-line executable. If set, this will replace the argument
        string generated by giving command etc. in the constructor.

        Args:
            value (str): A string containing the command-line arguments for the executable.
        """
        self.Arguments = value

    @property
    def input_file_name(self) -> str:
        """
        Gets the name of the Sesam Core input file.

        Returns:
            str: A string representing the name of the Sesam Core input file.
        """
        return self.InputFilename

    @input_file_name.setter
    def input_file_name(self, value: str):
        """
        Sets the name of the Sesam Core input file.

        Args:
            value (str): The name of the Sesam Core input file.
        """
        self.InputFilename = value

    @property
    def command(self) -> str:
        """
        Gets the Sesam Core command to run.

        Returns:
            str: A string representing the Sesam Core command to run.
        """
        return self.Command

    @command.setter
    def command(self, value: str):
        """
        Sets the Sesam Core command to run.

        Args:
            value (str): The Sesam Core command to run.
        """
        self.Command = value

    @property
    def options(self) -> str:
        """
        Gets the options to use with Sesam Core excluding the input file.

        Returns:
            str: A string representing the options to use with Sesam Core excluding the input file.
        """
        return self.Options

    @options.setter
    def options(self, value: str):
        """
        Sets the options to use with Sesam Core excluding the input file.

        Args:
            value (str): The options to use with Sesam Core excluding the input file.
        """
        self.Options = value

    @property
    def executable_folder(self) -> str:
        """
        Gets the executable folder for Sesam Core.

        Returns:
            str: A string representing the executable folder for Sesam Core.
        """
        return self.ExecutableFolder

    @executable_folder.setter
    def executable_folder(self, value: str):
        """
        Sets the executable folder for Sesam Core.

        Args:
            value (str): The executable folder for Sesam Core.
        """
        self.ExecutableFolder = value
